==> nico_sc_sp-0.0.6-py3-none-any.whl: nico/__init__.py <==
from nico.Annotations import create_directory
from nico.Annotations import find_index
from nico.Annotations import find_match_index_in_dist
from nico.Annotations import find_mutual_nn
from nico.Annotations import sct_return_sc_sp_in_shared_common_PC_space
from nico.Annotations import find_annotation_index
from nico.Annotations import find_commnon_MNN
from nico.Annotations import visualize_spatial_anchored_cell_mapped_to_scRNAseq
from nico.Annotations import find_anchor_cells_between_ref_and_query
from nico.Annotations import nico_based_annotation
from nico.Annotations import read_dist_and_nodes_as_graph
from nico.Annotations import return_singlecells
from nico.Annotations import findSpatialCells
from nico.Annotations import find_all_the_spatial_cells_mapped_to_single_cells
from nico.Annotations import write_annotation
from nico.Annotations import find_unmapped_cells_and_deg
from nico.Annotations import resolved_confused_and_unmapped_mapping_of_cells_with_weighted_average_of_inverse_distance_in_neighbors
from nico.Annotations import resolved_confused_and_unmapped_mapping_of_cells_with_majority_vote
from nico.Annotations import visualize_umap_and_cell_coordinates_with_all_celltypes
from nico.Annotations import visualize_umap_and_cell_coordinates_with_selected_celltypes
from nico.Annotations import remove_extra_character_from_name
from nico.Annotations import plot_all_ct
from nico.Annotations import plot_specific_ct
from nico.Annotations import sort_index_in_right_order
from nico.Covariations import gene_covariation_analysis
from nico.Covariations import plot_cosine_and_spearman_correlation_to_factors
from nico.Covariations import plot_feature_matrices
from nico.Covariations import plot_signifant_regression_covariations
from nico.Covariations import find_LR_interactions_in_interacting_cell_types
from nico.Covariations import make_excel_sheet_for_gene_correlation
from nico.Covariations import pathway_analysis
from nico.Covariations import plot_top_selected_genes_as_dotplot
from nico.Covariations import create_directory
from nico.Covariations import find_index
from nico.Covariations import read_spatial_data
from nico.Covariations import find_correlation_bw_genes_and_PC_component_in_singlecell
from nico.Covariations import find_correlation_bw_genes_and_PC_component_in_singlecell_cosine
from nico.Covariations import top_genes_in_correlation_list_without
from nico.Covariations import alignment_score
from nico.Covariations import multiplicative_method
from nico.Covariations import remove_extra_character_from_name
from nico.Covariations import find_PC_of_invidualCluster_in_SC
from nico.Covariations import makePCneighboorhoodFeatureMatrix
from nico.Covariations import compute_PC_space
from nico.Covariations import model_linear_regression
from nico.Covariations import run_ridge_regression
from nico.Covariations import find_logistic_regression_interacting_score
from nico.Covariations import findXYZC
from nico.Covariations import create_subtitle
from nico.Covariations import find_fold_change
from nico.Covariations import sorting_of_factors_for_showing_the_value_in_excelsheet
from nico.Covariations import triangulation_for_triheatmap
from nico.Covariations import  plot_ligand_receptor_in_interacting_celltypes
from nico.Covariations import visualize_factors_in_scRNAseq_umap
from nico.Covariations import plot_all_ct
from nico.Covariations import visualize_factors_in_spatial_umap
from nico.Covariations import read_LigRecDb
from nico.Covariations import sort_index_in_right_order
from nico.Interactions import create_directory
from nico.Interactions import findNeighbors_in_given_radius
from nico.Interactions import find_neighbors
from nico.Interactions import create_spatial_CT_feature_matrix
from nico.Interactions import euclidean_dist
from nico.Interactions import reading_data
from nico.Interactions import plot_multiclass_roc
from nico.Interactions import plot_roc_results
from nico.Interactions import plot_confusion_matrix
from nico.Interactions import plot_coefficient_matrix
from nico.Interactions import plot_predicted_probabilities
from nico.Interactions import plot_niche_interactions_with_edge_weight
from nico.Interactions import plot_niche_interactions_without_edge_weight
from nico.Interactions import read_processed_data
from nico.Interactions import model_log_regression
from nico.Interactions import find_interacting_cell_types
from nico.Interactions import remove_extra_character_from_name
from nico.Interactions import spatial_neighborhood_analysis
from nico.Interactions import plot_evaluation_scores

==> nico_sc_sp-1.1.0-py3-none-any.whl: nico/__init__.py <==
from nico.Annotations import create_directory
from nico.Annotations import find_index
from nico.Annotations import find_match_index_in_dist
from nico.Annotations import find_mutual_nn
from nico.Annotations import sct_return_sc_sp_in_shared_common_PC_space
from nico.Annotations import find_annotation_index
from nico.Annotations import find_commnon_MNN
from nico.Annotations import visualize_spatial_anchored_cell_mapped_to_scRNAseq
from nico.Annotations import find_anchor_cells_between_ref_and_query
from nico.Annotations import nico_based_annotation
from nico.Annotations import read_dist_and_nodes_as_graph
from nico.Annotations import return_singlecells
from nico.Annotations import findSpatialCells
from nico.Annotations import find_all_the_spatial_cells_mapped_to_single_cells
from nico.Annotations import write_annotation
from nico.Annotations import find_unmapped_cells_and_deg
from nico.Annotations import resolved_confused_and_unmapped_mapping_of_cells_with_weighted_average_of_inverse_distance_in_neighbors
from nico.Annotations import resolved_confused_and_unmapped_mapping_of_cells_with_majority_vote
from nico.Annotations import visualize_umap_and_cell_coordinates_with_all_celltypes
from nico.Annotations import visualize_umap_and_cell_coordinates_with_selected_celltypes
from nico.Annotations import remove_extra_character_from_name
from nico.Annotations import plot_all_ct
from nico.Annotations import plot_specific_ct
from nico.Annotations import sort_index_in_right_order
from nico.Annotations import delete_files
from nico.Covariations import plot_significant_regression_covariations_as_circleplot
from nico.Covariations import plot_significant_regression_covariations_as_heatmap
from nico.Covariations import save_LR_interactions_in_excelsheet_and_regression_summary_in_textfile_for_interacting_cell_types
from nico.Covariations import extract_and_plot_top_genes_from_chosen_factor_in_celltype
from nico.Covariations import plot_top_genes_for_pair_of_celltypes_from_two_chosen_factors
from nico.Covariations import plot_top_genes_for_a_given_celltype_from_all_three_factors
from nico.Covariations import find_interest_of_genes
from nico.Annotations import save_annotations_in_spatial_object
from nico.Covariations import gene_covariation_analysis
from nico.Covariations import plot_cosine_and_spearman_correlation_to_factors
from nico.Covariations import plot_feature_matrices
from nico.Covariations import find_LR_interactions_in_interacting_cell_types
from nico.Covariations import make_excel_sheet_for_gene_correlation
from nico.Covariations import pathway_analysis
from nico.Covariations import create_directory
from nico.Covariations import find_index
from nico.Covariations import read_spatial_data
from nico.Covariations import find_correlation_bw_genes_and_PC_component_in_singlecell
from nico.Covariations import find_correlation_bw_genes_and_PC_component_in_singlecell_cosine
from nico.Covariations import top_genes_in_correlation_list_without
from nico.Covariations import alignment_score
from nico.Covariations import multiplicative_method
from nico.Covariations import remove_extra_character_from_name
from nico.Covariations import find_PC_of_invidualCluster_in_SC
from nico.Covariations import makePCneighboorhoodFeatureMatrix
from nico.Covariations import compute_PC_space
from nico.Covariations import model_linear_regression
from nico.Covariations import run_ridge_regression
from nico.Covariations import find_logistic_regression_interacting_score
from nico.Covariations import findXYZC
from nico.Covariations import create_subtitle
from nico.Covariations import find_fold_change
from nico.Covariations import sorting_of_factors_for_showing_the_value_in_excelsheet
from nico.Covariations import triangulation_for_triheatmap
from nico.Covariations import  plot_ligand_receptor_in_interacting_celltypes
from nico.Covariations import visualize_factors_in_scRNAseq_umap
from nico.Covariations import plot_all_ct
from nico.Covariations import visualize_factors_in_spatial_umap
from nico.Covariations import read_LigRecDb
from nico.Covariations import sort_index_in_right_order
from nico.Interactions import create_directory
from nico.Interactions import findNeighbors_in_given_radius
from nico.Interactions import find_neighbors
from nico.Interactions import create_spatial_CT_feature_matrix
from nico.Interactions import euclidean_dist
from nico.Interactions import reading_data
from nico.Interactions import plot_multiclass_roc
from nico.Interactions import plot_roc_results
from nico.Interactions import plot_confusion_matrix
from nico.Interactions import plot_coefficient_matrix
from nico.Interactions import plot_predicted_probabilities
from nico.Interactions import plot_niche_interactions_with_edge_weight
from nico.Interactions import plot_niche_interactions_without_edge_weight
from nico.Interactions import read_processed_data
from nico.Interactions import model_log_regression
from nico.Interactions import find_interacting_cell_types
from nico.Interactions import remove_extra_character_from_name
from nico.Interactions import spatial_neighborhood_analysis
from nico.Interactions import plot_evaluation_scores
__version__ = '1.1.0'
